Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog
<https://keepachangelog.com/en/1.0.0/>`_
with additional group for informations,
and this project adheres to `Semantic Versioning
<https://semver.org/spec/v2.0.0.html>`_.

[1.0.2] - 2021-08-08
--------------------

Changed
~~~~~~~
- Updated package on PyPi


[1.0.1] - 2021-08-08
--------------------

Added
~~~~~
- Bumpversion configuration
- Example to README file

Changed
~~~~~~~
- Category for pip

Fixed
~~~~~
- Path to ssh configuration file

[1.0.0] - 2021-08-08
--------------------

Added
~~~~~
- Basic functionality
